@@ -1,3 +1,4 @@
+__version__ = '0.2.8'
 # Copyright (c) 2013. SlickLog.
 __author__ = 'Torindo Nesci'
 
@@ -11,6 +12,7 @@ from .util import new_queue
 from .util import queue_mod
 from .util import httplib_mod
 from .util import quote_p
+from .util import os_platform
 
 
 class ConnectionBuilder:
@@ -25,6 +27,8 @@ class ConnectionBuilder:
   __HTTP_CONTENT_TYPE_VALUE = 'text/plain; charset=utf-8'
   __HTTP_CONTENT_LENGTH_HEADER = 'Content-Length'
   __HTTP_CONTENT_LENGTH_VALUE = '512000'
+  __HTTP_USER_AGENT_HEADER = 'User-Agent'
+  __HTTP_USER_AGENT_VALUE = 'PyRemoteLogger ' + __version__ + ': ' + os_platform()
   __API_KEY = 'apiKey'
   __LOG_GROUP_NAME = 'logGroupName'
   __LOG_NAME = 'logName'
@@ -90,6 +94,7 @@ class ConnectionBuilder:
       conn.putrequest(ConnectionBuilder.__HTTP_METHOD, url)
       conn.putheader(ConnectionBuilder.__HTTP_CONTENT_TYPE_HEADER, ConnectionBuilder.__HTTP_CONTENT_TYPE_VALUE)
       conn.putheader(ConnectionBuilder.__HTTP_CONTENT_LENGTH_HEADER, ConnectionBuilder.__HTTP_CONTENT_LENGTH_VALUE)
+      conn.putheader(ConnectionBuilder.__HTTP_USER_AGENT_HEADER, ConnectionBuilder.__HTTP_USER_AGENT_VALUE)
       conn.endheaders()
     except Exception as ex:
       log('Connection error: {0}', str(ex))
